@@ -81,6 +81,7 @@ class Camera(BaseCamera):
         # i need these to be in globals() ----evaluate from web.py
         global substract_background,save_background
         global speedx, speedy, restart_translate, average
+        global gamma_divide, gamma_multiply,gamma_setdef,gain_divide,gain_multiply,gain_setdef
 
         # print("i... staticmethod frames @ real -  enterred; target_frame==", target_frame)
         senh = Stream_Enhancer()
@@ -100,6 +101,12 @@ class Camera(BaseCamera):
         substract_background = False
         save_background = False
         restart_translate = False
+        gamma_divide = False
+        gamma_multiply =False
+        gamma_setdef =False
+        gain_divide = False
+        gain_multiply =False
+        gain_setdef =False
 
         camera = Camera(  )
         cap, vidnum = camera.init_cam(  )
@@ -249,9 +256,9 @@ class Camera(BaseCamera):
                         save_background = False  # ONE SHOT
 
                     if substract_background:
-                        print("D... HERE I MUST DO subtraction of mask")
-                        print("D... HERE I MUST DO subtraction of mask")
-                        print("D... HERE I MUST DO subtraction of mask")
+                        # print("D... HERE I MUST DO subtraction of mask")
+                        # print("D... HERE I MUST DO subtraction of mask")
+                        print("D... HERE I MUST DO subtraction of mask",speedx, speedy)
                         senh.subtract()
 
                     # - compensate for speed of the sky
@@ -262,9 +269,40 @@ class Camera(BaseCamera):
                         senh.reset_camera_start()
                         restart_translate = False
 
-                    # average  THIS IS HERE to be changed TOO
+                    # average  THIS IS HERE to be changed TOO (ACCUM)
                     # print("i.... average", average)
 
+                    #print("i... GAMMAS ", gamma, gammadef )
+                    if gamma_divide:
+                        gamma_divide = False
+                        if "gamma" in capa:
+                            cc.set_gamma( int(gamma/2) )
+
+                    if gamma_multiply:
+                        gamma_multiply = False
+                        if "gamma" in capa:
+                            cc.set_gamma( int(gamma*2) )
+
+                    if gamma_setdef:
+                        gamma_setdef = False
+                        if "gamma" in capa:
+                            cc.setdef_gamma( )
+
+                    if gain_divide:
+                        gain_divide = False
+                        if "gain" in capa:
+                            cc.set_gain( int(gain/2) )
+
+                    if gain_multiply:
+                        gain_multiply = False
+                        if "gain" in capa:
+                            cc.set_gain( int(gain*2) )
+
+                    if gain_setdef:
+                        gain_setdef = False
+                        if "gain" in capa:
+                            cc.setdef_gain( )
+
 
                     #--------------- now apply labels ------i cannot get rid in DETM---
                     #--------- all this will be on all rames histo,detect,direct,delta
@@ -288,17 +326,19 @@ class Camera(BaseCamera):
                         senh.setbox(f"y {speedy:.3f}",  senh.speedy)
 
 
+                    # ----------------expo gain gamma
                     # very stupid camera    ZC0303 Webcam
                     if "exposure" in capa:
                         if exposure!=exposuredef: # manual
                             senh.setbox(f"expo {exposure}",  senh.expo)
 
-
                     if "exposure_auto" in capa:
                         if expo_auto!=expo_autodef: # manual
                             senh.setbox(f"expo {exposure_absolute}",  senh.expo)
+
                     if ("gain" in capa) and (gain!=gaindef): # gain is not frequently tunable
                         senh.setbox(f"g {gain}",  senh.gain)
+
                     if ("gamma" in capa):
                         if (gamma!=gammadef): # manual
                             senh.setbox(f"m {gamma}",  senh.gamma)
