@@ -331,8 +331,8 @@ class Stream_Enhancer:
 
 #-------------------------------------------- ENDOF LABELS----------
     def save_background(self):
-        cv2.imwrite( self.BGFILE , self.frame )
-        self.frame_bg = self.frame
+        cv2.imwrite( self.BGFILE , self.frame ) # nicely saved
+        self.frame_bg = self.frame.copy() # else artifacts remain
         # frame_bg = self.frame.copy()
         # frame_bg2 = cv2.imencode('.jpg', frame_bg)[1].tobytes()
         # save_bg = False
