@@ -28,7 +28,7 @@ from flask import request
 #===== another auth.
 from flask_httpauth import HTTPBasicAuth
 
-import pantilthat
+# import pantilthat
 
 # block stuff depending on PC
 import socket
@@ -43,6 +43,22 @@ from flashcam.real_camera import Camera
 #----------------------------------------------
 from flashcam.mmapwr import mmwrite
 
+try:
+    import pantilthat
+except:
+    class pantilthat:
+        @classmethod
+        def tilt(self,a):
+            return
+        @classmethod
+        def pan(self,a):
+            return
+        @classmethod
+        def get_tilt(self):
+            return 0
+        @classmethod
+        def get_pan(self):
+            return 0
 
 
 
@@ -158,15 +174,24 @@ setInterval(doDate, 200);
       <button style="width:8%" name="subbg" value="SUBBG">subBG</button>
  <img src="{{url_bg}}" alt="Smiley face"  height="120" width="160" />
 <hr>
-  <p>    <button style="width:8%" name="speedx" value="SPEEDX">dXdY</button>
-      <!--button style="width:8%" name="speedy" value="SPEEDY">dY</button-->
-dx <input type = "text" name = "inputx"  size="6" />  dy <input type = "text" name = "inputy" size="6" />
+      <button style="width:4%" name="speedx" value="SPEEDX">dX</button>
+    <input type = "text" name = "inputx"  size="6" />
+      <button style="width:4%" name="speedy" value="SPEEDY">dY</button>
+    <input type = "text" name = "inputy" size="6" />
 
       <button style="width:8%" name="restart_translate" value="RESTART_TRANSLATE">restart</button>
       <button style="width:8%" name="zero_translate" value="ZERO_TRANSLATE">zero</button>
 <br>
-   <p>   <button style="width:8%" name="accum" value="ACCUM">Accum</button>
-      accum <input type = "text" name = "accumtxt" size="6" /></p>
+      <button style="width:8%" name="accum" value="ACCUM">Accum</button>
+      &nbsp; &nbsp;&nbsp; <input type = "text" name = "accumtxt" size="6" />
+<hr>
+      <button style="width:8%" name="gamma2" value="GAMMA2">gm x2</button>
+      <button style="width:8%" name="gamma05" value="GAMMA05">gm /2</button>
+      <button style="width:8%" name="gamma" value="GAMMA">gm def</button>
+      <button style="width:8%" name="gain2" value="GAIN2">ga x2</button>
+      <button style="width:8%" name="gain05" value="GAIN05">ga /2</button>
+      <button style="width:8%" name="gain" value="GAIN">ga def</button>
+
   </div>
 
 </form>
@@ -235,32 +260,48 @@ def cross():
             speedx = request.form.get('inputx')
             try:
                 speedx = float(speedx)
+                print("i...  X",  speedx)
+                mmwrite(f"speedx {speedx}" )
             except:
-                speedx = 0.0
-            print("i...  X",  speedx)
-            mmwrite(f"speedx {speedx}" )
+                print("D... unknown value speedx")
 
-        #if request.form.get('speedy') == 'SPEEDY':
+        if request.form.get('speedy') == 'SPEEDY':
+            #time.sleep(0.2)  #=============== PROBLEM FOR SLOW FRAMES!
             speedy = request.form.get('inputy')
             try:
                 speedy = float(speedy)
+                print("i...  Y",  speedy)
+                mmwrite(f"speedy {speedy}" )
             except:
-                speedy = 0.0
-            print("i...  Y",  speedy)
-            #print("i... Y" )
-            time.sleep(0.2)
-            mmwrite(f"speedy {speedy}" )
+                print("D... unknown value speedy")
 
         if request.form.get('restart_translate') == 'RESTART_TRANSLATE':
             mmwrite(f"restart_translate True" )
 
         if request.form.get('zero_translate') == 'ZERO_TRANSLATE':
             mmwrite(f"speedx {0}" )
-            time.sleep(0.2)
+            time.sleep(0.2) #================ PROBLEM FOR SLOW
             mmwrite(f"speedy {0}" )
 
+        if request.form.get('gamma2') == 'GAMMA2':
+            mmwrite(f"gamma_multiply True" )
+        if request.form.get('gamma05') == 'GAMMA05':
+            mmwrite(f"gamma_divide True" )
+        if request.form.get('gamma') == 'GAMMA':
+            mmwrite(f"gamma_setdef True" )
+
+        if request.form.get('gain2') == 'GAIN2':
+            mmwrite(f"gain_multiply True" )
+        if request.form.get('gain05') == 'GAIN05':
+            mmwrite(f"gain_divide True" )
+        if request.form.get('gain') == 'GAIN':
+            mmwrite(f"gain_setdef True" )
 
 
+
+
+
+        # --------------------------------- Cross controls
         if cross_on:
             if request.form.get('left2') == 'LEFT2':
                 print("left2")
@@ -290,6 +331,40 @@ def cross():
             elif  request.form.get('down2') == 'DOWN2':
                 print("down2")
                 cross_dy+= 50
+        else: # ---------------------------- PANTILT MODE
+            if request.form.get('down') == 'DOWN':
+                print("v")
+                if (pantilthat.get_tilt()-2)>=-90:
+                    pantilthat.tilt( pantilthat.get_tilt()-2  )
+            if request.form.get('up') == 'UP':
+                print("^")
+                if (pantilthat.get_tilt()+2)<=90:
+                    pantilthat.tilt( pantilthat.get_tilt()+2 )
+            if request.form.get('right') == 'RIGHT':
+                print("->")
+                if (pantilthat.get_pan()-2)>=-90:
+                    pantilthat.pan( pantilthat.get_pan()-2 )
+            if request.form.get('left') == 'LEFT':
+                print("<-")
+                if (pantilthat.get_pan()+2)<=90:
+                    pantilthat.pan( pantilthat.get_pan()+2 )
+
+            if request.form.get('down2') == 'DOWN2':
+                print("v")
+                if (pantilthat.get_tilt()-8)>=-90:
+                    pantilthat.tilt( pantilthat.get_tilt()-8  )
+            if request.form.get('up2') == 'UP2':
+                print("^")
+                if (pantilthat.get_tilt()+8)<=90:
+                    pantilthat.tilt( pantilthat.get_tilt()+8 )
+            if request.form.get('right2') == 'RIGHT2':
+                print("->")
+                if (pantilthat.get_pan()-8)>=-90:
+                    pantilthat.pan( pantilthat.get_pan()-8 )
+            if request.form.get('left2') == 'LEFT2':
+                print("<-")
+                if (pantilthat.get_pan()+8)<=90:
+                    pantilthat.pan( pantilthat.get_pan()+8 )
 
         if  request.form.get('crosson') == 'CROSSON':
             print("ON")
